@@ -1133,7 +1133,7 @@ class LaharFlowData(object):
         cols = csv_active_cols(LaharFlowFile)
         return cols
 
-    def _get_data_txt(self, LaharFlowFile, var=None):
+    def _get_data_txt(self, LaharFlowFile, vars=None):
         try:
             data = pd.read_csv(
                 LaharFlowFile,
@@ -1142,8 +1142,8 @@ class LaharFlowData(object):
                 index_col=["y_distance", "x_distance"],
             )
 
-            if var is not None:
-                drop_vars = [d for d in data.columns if d not in var]
+            if vars is not None:
+                drop_vars = [d for d in data.columns if d not in vars]
                 data.drop(columns=drop_vars, axis=1, inplace=True)
 
             raster = xa.Dataset.from_dataframe(data)
@@ -1156,9 +1156,9 @@ class LaharFlowData(object):
         except:
             raise RuntimeWarning("Unable to get data from {}".format(LaharFlowFile))
 
-    def _get_data_nc(self, LaharFlowFile, var=None):
+    def _get_data_nc(self, LaharFlowFile, vars=None):
 
-        raster = nc2xr(LaharFlowFile, var=var)
+        raster = nc2xr(LaharFlowFile, vars=vars)
         raster = raster.rename({"x_distance": "x", "y_distance": "y"})
         raster["x"] = raster["x"] + self.utm[0]
         raster["y"] = raster["y"] + self.utm[1]
@@ -1166,7 +1166,7 @@ class LaharFlowData(object):
 
         return raster
 
-    def _get_data(self, filename, var=None):
+    def _get_data(self, filename, vars=None):
 
         filename = self._valid_input_file(filename)
 
@@ -1175,10 +1175,10 @@ class LaharFlowData(object):
         fileext = os.path.splitext(LaharFlowFile)[1]
 
         if fileext == ".txt":
-            return self._get_data_txt(LaharFlowFile, var=var)
+            return self._get_data_txt(LaharFlowFile, vars=vars)
         elif fileext == ".nc":
             try:
-                d = self._get_data_nc(LaharFlowFile, var=var)
+                d = self._get_data_nc(LaharFlowFile, vars=vars)
             except:
                 print("Could not load netcdf file " + LaharFlowFile)
                 d = None
@@ -1235,7 +1235,7 @@ class LaharFlowData(object):
     def raster(
         self,
         filename,
-        var=None,
+        vars=None,
         full_domain=False,
         nodata=np.nan,
         masked=True,
@@ -1246,7 +1246,7 @@ class LaharFlowData(object):
         filetype = self._file_type(filename)
         filename = self._valid_input_file(filename)
 
-        raster = self._get_data(filename, var=var)
+        raster = self._get_data(filename, vars=vars)
 
         # if var is not None:
         #     raster = raster[var]
@@ -1829,7 +1829,7 @@ class LaharFlowData(object):
 
         fileIn = self._valid_input_file(fileIn)
 
-        raster = self.raster(fileIn)
+        raster = self.raster(fileIn, vars=vars)
         data_vars = raster.data_vars
 
         if vars is not None:
